@@ -12,8 +12,10 @@ Date:    2020/09/25 08:11:00
 """
 
 from easytext.data.pretrained_word_embedding_loader import GeneralPretrainedWordEmbeddingLoader
+from easytext.component.register import EasytextRegister
 
 
+@EasytextRegister.register()
 class SGNSLoader(GeneralPretrainedWordEmbeddingLoader):
     """
     SGNS Word Embedding Loader.
