@@ -13,3 +13,5 @@ Date:    2020/06/23 11:58:00
 
 from .conditional_random_field import ConditionalRandomField
 from .dynamic_rnn import DynamicRnn, DynamicRnnOutput
+from .lattice_lstm import LatticeLSTM
+from .gat import GraphAttentionLayer, GAT
